# imports 
import sys
import os

#
# this is a general helper module providing some basic functions to 
# e.g. run CODESYS or another process with certain arguments
#
#

from System.Diagnostics import Process
from System.Net import WebClient

def RunProcess(workdir, process, args):
	exitcode = -1
	print("run process: " + process + " " + args)
	if not os.path.exists(workdir):
		print("Path does not exist: " + workdir)
	if not os.path.exists(os.path.join(workdir, process)):
		print("File does not exist: " + process)
	else:
		p = Process()
		p.StartInfo.WorkingDirectory=workdir
		p.StartInfo.FileName = process
		p.StartInfo.Arguments =  args
		p.Start()
		p.WaitForExit()
		exitcode = p.ExitCode
	print("done: " + str(exitcode))
	return exitcode


def RunCodesysWithScript(scriptfilename, scriptargs=None):
	print(scriptfilename)
	# common paths
	workingdir = os.path.dirname(sys.argv[0])
	cdsdir = os.path.abspath(os.path.join(workingdir, os.path.pardir, os.path.pardir))
	#print(cdsdir)

	# profile stuff
	profiledir=os.path.join(cdsdir,"Profiles")
	#print(profiledir)
	lastprofile=""
	for file in os.listdir(profiledir):
		if file.endswith(".profile"):
			lastprofile = file.replace(".profile","")
	#print(lastprofile)

	# exe
	codesys_exe = os.path.join(cdsdir, "Common", "CODESYS.exe")
	packageman_exe = os.path.join(cdsdir, "Common", "PackageManager.exe")
	workdir = os.path.join(cdsdir, "Common")
	exitcode = -1
	if not os.path.exists(os.path.join(workingdir,scriptfilename)):
		print("File does not exist: " + scriptfilename)

	else:
		p = Process()
		p.StartInfo.WorkingDirectory=workdir
		p.StartInfo.FileName = codesys_exe
		
		processargs = "--profile='" + lastprofile + "'  --runscript='" + os.path.join(workingdir,scriptfilename) + "'" 
		processargs += " --noUI"
		if scriptargs != None:
			processargs += " --scriptargs:'" + scriptargs + "'"
		print("running codesys with script " + scriptfilename)
		p.StartInfo.Arguments =  processargs
		p.Start()
		p.WaitForExit()
		
		exitcode = p.ExitCode 

	print("done: " + str(exitcode))
	return exitcode

			
